
;
; The Doctor presents...
;
;   BatTime.Com : Batch file time checking utility.
;
;
; Accepted parameters :
;  D : Display time (HH.MM, 24-hour)
;  H : Return hours to errorlevel (24-hour, 0=midnight ... 23=11PM)
;  M : Return minutes to errorlevel (0..59)
;  S : Return seconds to errorlevel (0..59)
;  P : Return percent of seconds (hundredths) to errorlevel
;  ? : Display syntax : BatTime {[D][M|H]|?}
;
; If no parameter, will display syntax, as if -? was given.
;

code      segment   byte      'Code'
          assume    CS:Code

          org       00100h

Start:    push      CS
          pop       DS
          mov       AH,02Ch
          int       021h
          mov       CS:TimeH,CH
          mov       CS:TimeM,CL
          mov       CS:TimeS,DH
          mov       CS:TimeP,DL
          mov       CL,CS:[00080h]
          cmp       CL,001h
          jg        Called
          call      DoTitle
          int       020h
Called:   mov       BX,00081h
          xor       CH,CH
STLoop:   mov       AL,[BX]
          cmp       AL,"?"
          jne       NSTDT
          call      DoTitle
NSTDT:    and       AL,0DFh
          cmp       AL,"D"
          jne       NSTDD
          call      DoTime
NSTDD:    cmp       AL,"H"
          je        RetHours
          cmp       AL,"M"
          je        RetMins
          cmp       AL,"S"
          je        RetSecs
          cmp       AL,"P"
          je        RetPSecs
          inc       BX
          loop      STLoop
          int       020h

RetHours: mov       AL,CS:TimeH
Return:   mov       AH,04Ch
          int       021h

RetMins:  mov       AL,CS:TimeM
          jmp short Return

RetSecs:  mov       AL,CS:TimeS
          jmp short Return

RetPSecs: mov       AL,CS:TimeP
          jmp short Return

DoTitle:  push      AX
          push      DX
          mov       AH,009h
          mov       DX,offset Title1
          int       021h
          pop       DX
          pop       AX
          ret

DoTime:   push      AX
          push      BX
          push      CX
          push      DX
          mov       CX,offset String
          mov       DX,CX
          mov       AL,CS:TimeH
          xor       AH,AH
          mov       BL,00Ah
          div       BL
          call      Digit
          mov       AL,AH
          call      Digit
          inc       CX
          mov       AL,CS:TimeM
          xor       AH,AH
          mov       BL,00Ah
          div       BL
          call      Digit
          mov       AL,AH
          call      Digit
          mov       AH,009h
          int       021h
          pop       DX
          pop       CX
          pop       BX
          pop       AX
          ret

Digit:    push      DX
          mov       BL,AL
          xor       BH,BH
          add       BX,offset Digits
          mov       DL,CS:[BX]
          xchg      BX,CX
          mov       CS:[BX],DL
          inc       BX
          xchg      BX,CX
          pop       DX
          ret

TimeH     db        000h
TimeM     db        000h
TimeS     db        000h
TimeP     db        000h

Title1    db        13,10
          db        "The Doctor presents... BatTime (0.1a) batch-file time determination utility",13,10
          db        13,10
          db        "Command syntax is : BATTIME [[-]option[[-]option[..]]]",13,10
          db        13,10
          db        "Option is one of the below :",13,10
          db        "  ? : Display this information",13,10
          db        "  D : Display current time (24-hour format : HH.MM) at cursor",13,10
          db        "  H : Return hours in error-level (0=midnight, 23=11PM)",13,10
          db        "  M : Return minutes in error-level (0..59)",13,10
          db        "  S : Return seconds in error-level (0..59)",13,10
          db        "  P : Return percent of a second in error-level (0..99)",13,10
          db        13,10
          db        "If no parameters included, it is assumed that you need help, so this is",13,10
          db        "displayed, as if you had used the `?' option.",13,10
          db        "$"

Digits    db        "0123456789"

String    db        "  .  $"

;
; This is so the program fills to the end of the sector.
;
Fill:     if ($-Start) mod 512
           db (512-(($-Start) mod 512)) dup (000h)
          endif

code      ends
          end       Start
